==> jc-1.4.0.tar.gz: java/security/spec/PSSParameterSpec.h <==
// public class java.security.spec.PSSParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e9efdffce7fa36fc java_security_spec_PSSParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_PSSParameterSpec_H_
#define _JC_java_security_spec_PSSParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_security_spec_PSSParameterSpec$sub_refs	_jc_java_security_spec_PSSParameterSpec$sub_refs;
typedef struct _jc_java_security_spec_PSSParameterSpec$sub_nonrefs	_jc_java_security_spec_PSSParameterSpec$sub_nonrefs;
typedef struct _jc_java_security_spec_PSSParameterSpec$refs	_jc_java_security_spec_PSSParameterSpec$refs;
typedef struct _jc_java_security_spec_PSSParameterSpec$nonrefs	_jc_java_security_spec_PSSParameterSpec$nonrefs;
typedef struct _jc_java_security_spec_PSSParameterSpec$object	_jc_java_security_spec_PSSParameterSpec$object;

typedef const struct _jc_java_security_spec_PSSParameterSpec$vmethods	_jc_java_security_spec_PSSParameterSpec$vmethods;
typedef const struct _jc_java_security_spec_PSSParameterSpec$vtable	_jc_java_security_spec_PSSParameterSpec$vtable;
typedef const struct _jc_java_security_spec_PSSParameterSpec$vtype	_jc_java_security_spec_PSSParameterSpec$vtype;

// Constructors
extern void _jc_java_security_spec_PSSParameterSpec$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_security_spec_PSSParameterSpec$object *, jint);

// Virtual methods
extern jint _jc_java_security_spec_PSSParameterSpec$method$getSaltLength$e8414ffe7c61187e(_jc_env *, struct _jc_java_security_spec_PSSParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_PSSParameterSpec$method_info$getSaltLength$e8414ffe7c61187e;

// Virtual methods structure
struct _jc_java_security_spec_PSSParameterSpec$vmethods {
	jint	(*getSaltLength$e8414ffe7c61187e)(_jc_env *, struct _jc_java_security_spec_PSSParameterSpec$object *);
};

// Vtable
struct _jc_java_security_spec_PSSParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_PSSParameterSpec$vmethods	java_security_spec_PSSParameterSpec;
};

// Vtype
struct _jc_java_security_spec_PSSParameterSpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_PSSParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_PSSParameterSpec$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_spec_PSSParameterSpec$refs {
    _jc_java_security_spec_PSSParameterSpec$sub_refs	java_security_spec_PSSParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_PSSParameterSpec$sub_nonrefs {
	jint	saltLen;
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_PSSParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_PSSParameterSpec$sub_nonrefs	java_security_spec_PSSParameterSpec;
};

// Object instance structure
struct _jc_java_security_spec_PSSParameterSpec$object {
	_jc_java_security_spec_PSSParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_PSSParameterSpec$vtype	*vtype;
	_jc_java_security_spec_PSSParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_PSSParameterSpec$vtype _jc_java_security_spec_PSSParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_PSSParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_PSSParameterSpec$class_object;

#endif	/* _JC_java_security_spec_PSSParameterSpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/PSSParameterSpec.h <==
// public class java.security.spec.PSSParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e9efdffce7fa36fc java_security_spec_PSSParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_PSSParameterSpec_H_
#define _JC_java_security_spec_PSSParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_security_spec_PSSParameterSpec$sub_refs	_jc_java_security_spec_PSSParameterSpec$sub_refs;
typedef struct _jc_java_security_spec_PSSParameterSpec$sub_nonrefs	_jc_java_security_spec_PSSParameterSpec$sub_nonrefs;
typedef struct _jc_java_security_spec_PSSParameterSpec$refs	_jc_java_security_spec_PSSParameterSpec$refs;
typedef struct _jc_java_security_spec_PSSParameterSpec$nonrefs	_jc_java_security_spec_PSSParameterSpec$nonrefs;
typedef struct _jc_java_security_spec_PSSParameterSpec$object	_jc_java_security_spec_PSSParameterSpec$object;

typedef const struct _jc_java_security_spec_PSSParameterSpec$vmethods	_jc_java_security_spec_PSSParameterSpec$vmethods;
typedef const struct _jc_java_security_spec_PSSParameterSpec$vtable	_jc_java_security_spec_PSSParameterSpec$vtable;
typedef const struct _jc_java_security_spec_PSSParameterSpec$vtype	_jc_java_security_spec_PSSParameterSpec$vtype;

// Constructors
extern void _jc_java_security_spec_PSSParameterSpec$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_security_spec_PSSParameterSpec$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_security_spec_PSSParameterSpec$method$getSaltLength$e8414ffe7c61187e(_jc_env *, struct _jc_java_security_spec_PSSParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_PSSParameterSpec$method_info$getSaltLength$e8414ffe7c61187e;

// Virtual methods structure
struct _jc_java_security_spec_PSSParameterSpec$vmethods {
	jint	(*getSaltLength$e8414ffe7c61187e)(_jc_env *, struct _jc_java_security_spec_PSSParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_PSSParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_PSSParameterSpec$vmethods	java_security_spec_PSSParameterSpec;
};

// Vtype
struct _jc_java_security_spec_PSSParameterSpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_PSSParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_PSSParameterSpec$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_spec_PSSParameterSpec$refs {
    _jc_java_security_spec_PSSParameterSpec$sub_refs	java_security_spec_PSSParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_PSSParameterSpec$sub_nonrefs {
	jint	saltLen;
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_PSSParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_PSSParameterSpec$sub_nonrefs	java_security_spec_PSSParameterSpec;
};

// Object instance structure
struct _jc_java_security_spec_PSSParameterSpec$object {
	_jc_java_security_spec_PSSParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_PSSParameterSpec$vtype	*vtype;
	_jc_java_security_spec_PSSParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_PSSParameterSpec$vtype _jc_java_security_spec_PSSParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_PSSParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_PSSParameterSpec$class_object;

#endif	/* _JC_java_security_spec_PSSParameterSpec_H_ */
